==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1WebhookFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.util.List;
import java.lang.Boolean;
import java.util.Collection;
import java.lang.Object;

public class V1beta1WebhookFluentImpl<A extends V1beta1WebhookFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta1WebhookFluent<A>{

    private V1beta1WebhookClientConfigBuilder clientConfig;
    private String failurePolicy;
    private String name;
    private V1LabelSelectorBuilder namespaceSelector;
    private List<V1beta1RuleWithOperationsBuilder> rules;

    public V1beta1WebhookFluentImpl(){
    }
    public V1beta1WebhookFluentImpl(V1beta1Webhook instance){
            this.withClientConfig(instance.getClientConfig());

            this.withFailurePolicy(instance.getFailurePolicy());

            this.withName(instance.getName());

            this.withNamespaceSelector(instance.getNamespaceSelector());

            this.withRules(instance.getRules());

    }

    
/**
 * This method has been deprecated, please use method buildClientConfig instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1WebhookClientConfig getClientConfig(){
            return this.clientConfig!=null?this.clientConfig.build():null;
    }

    public V1beta1WebhookClientConfig buildClientConfig(){
            return this.clientConfig!=null?this.clientConfig.build():null;
    }

    public A withClientConfig(V1beta1WebhookClientConfig clientConfig){
            _visitables.remove(this.clientConfig);
            if (clientConfig!=null){ this.clientConfig= new V1beta1WebhookClientConfigBuilder(clientConfig); _visitables.add(this.clientConfig);} return (A) this;
    }

    public Boolean hasClientConfig(){
            return this.clientConfig != null;
    }

    public V1beta1WebhookFluent.ClientConfigNested<A> withNewClientConfig(){
            return new ClientConfigNestedImpl();
    }

    public V1beta1WebhookFluent.ClientConfigNested<A> withNewClientConfigLike(V1beta1WebhookClientConfig item){
            return new ClientConfigNestedImpl(item);
    }

    public V1beta1WebhookFluent.ClientConfigNested<A> editClientConfig(){
            return withNewClientConfigLike(getClientConfig());
    }

    public V1beta1WebhookFluent.ClientConfigNested<A> editOrNewClientConfig(){
            return withNewClientConfigLike(getClientConfig() != null ? getClientConfig(): new V1beta1WebhookClientConfigBuilder().build());
    }

    public V1beta1WebhookFluent.ClientConfigNested<A> editOrNewClientConfigLike(V1beta1WebhookClientConfig item){
            return withNewClientConfigLike(getClientConfig() != null ? getClientConfig(): item);
    }

    public String getFailurePolicy(){
            return this.failurePolicy;
    }

    public A withFailurePolicy(String failurePolicy){
            this.failurePolicy=failurePolicy; return (A) this;
    }

    public Boolean hasFailurePolicy(){
            return this.failurePolicy != null;
    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    
/**
 * This method has been deprecated, please use method buildNamespaceSelector instead.
 * @return The buildable object.
 */
@Deprecated public V1LabelSelector getNamespaceSelector(){
            return this.namespaceSelector!=null?this.namespaceSelector.build():null;
    }

    public V1LabelSelector buildNamespaceSelector(){
            return this.namespaceSelector!=null?this.namespaceSelector.build():null;
    }

    public A withNamespaceSelector(V1LabelSelector namespaceSelector){
            _visitables.remove(this.namespaceSelector);
            if (namespaceSelector!=null){ this.namespaceSelector= new V1LabelSelectorBuilder(namespaceSelector); _visitables.add(this.namespaceSelector);} return (A) this;
    }

    public Boolean hasNamespaceSelector(){
            return this.namespaceSelector != null;
    }

    public V1beta1WebhookFluent.NamespaceSelectorNested<A> withNewNamespaceSelector(){
            return new NamespaceSelectorNestedImpl();
    }

    public V1beta1WebhookFluent.NamespaceSelectorNested<A> withNewNamespaceSelectorLike(V1LabelSelector item){
            return new NamespaceSelectorNestedImpl(item);
    }

    public V1beta1WebhookFluent.NamespaceSelectorNested<A> editNamespaceSelector(){
            return withNewNamespaceSelectorLike(getNamespaceSelector());
    }

    public V1beta1WebhookFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelector(){
            return withNewNamespaceSelectorLike(getNamespaceSelector() != null ? getNamespaceSelector(): new V1LabelSelectorBuilder().build());
    }

    public V1beta1WebhookFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelectorLike(V1LabelSelector item){
            return withNewNamespaceSelectorLike(getNamespaceSelector() != null ? getNamespaceSelector(): item);
    }

    public A addToRules(int index,V1beta1RuleWithOperations item){
            if (this.rules == null) {this.rules = new ArrayList<V1beta1RuleWithOperationsBuilder>();}
            V1beta1RuleWithOperationsBuilder builder = new V1beta1RuleWithOperationsBuilder(item);_visitables.add(index >= 0 ? index : _visitables.size(), builder);this.rules.add(index >= 0 ? index : rules.size(), builder); return (A)this;
    }

    public A setToRules(int index,V1beta1RuleWithOperations item){
            if (this.rules == null) {this.rules = new ArrayList<V1beta1RuleWithOperationsBuilder>();}
            V1beta1RuleWithOperationsBuilder builder = new V1beta1RuleWithOperationsBuilder(item);
            if (index < 0 || index >= _visitables.size()) { _visitables.add(builder); } else { _visitables.set(index, builder);}
            if (index < 0 || index >= rules.size()) { rules.add(builder); } else { rules.set(index, builder);}
             return (A)this;
    }

    public A addToRules(V1beta1RuleWithOperations... items){
            if (this.rules == null) {this.rules = new ArrayList<V1beta1RuleWithOperationsBuilder>();}
            for (V1beta1RuleWithOperations item : items) {V1beta1RuleWithOperationsBuilder builder = new V1beta1RuleWithOperationsBuilder(item);_visitables.add(builder);this.rules.add(builder);} return (A)this;
    }

    public A addAllToRules(Collection<V1beta1RuleWithOperations> items){
            if (this.rules == null) {this.rules = new ArrayList<V1beta1RuleWithOperationsBuilder>();}
            for (V1beta1RuleWithOperations item : items) {V1beta1RuleWithOperationsBuilder builder = new V1beta1RuleWithOperationsBuilder(item);_visitables.add(builder);this.rules.add(builder);} return (A)this;
    }

    public A removeFromRules(V1beta1RuleWithOperations... items){
            for (V1beta1RuleWithOperations item : items) {V1beta1RuleWithOperationsBuilder builder = new V1beta1RuleWithOperationsBuilder(item);_visitables.remove(builder);if (this.rules != null) {this.rules.remove(builder);}} return (A)this;
    }

    public A removeAllFromRules(Collection<V1beta1RuleWithOperations> items){
            for (V1beta1RuleWithOperations item : items) {V1beta1RuleWithOperationsBuilder builder = new V1beta1RuleWithOperationsBuilder(item);_visitables.remove(builder);if (this.rules != null) {this.rules.remove(builder);}} return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildRules instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1RuleWithOperations> getRules(){
            return build(rules);
    }

    public List<V1beta1RuleWithOperations> buildRules(){
            return build(rules);
    }

    public V1beta1RuleWithOperations buildRule(int index){
            return this.rules.get(index).build();
    }

    public V1beta1RuleWithOperations buildFirstRule(){
            return this.rules.get(0).build();
    }

    public V1beta1RuleWithOperations buildLastRule(){
            return this.rules.get(rules.size() - 1).build();
    }

    public V1beta1RuleWithOperations buildMatchingRule(io.kubernetes.client.fluent.Predicate<V1beta1RuleWithOperationsBuilder> predicate){
            for (V1beta1RuleWithOperationsBuilder item: rules) { if(predicate.apply(item)){return item.build();} } return null;
    }

    public A withRules(List<V1beta1RuleWithOperations> rules){
            if (this.rules != null) { _visitables.removeAll(this.rules);}
            if (rules != null) {this.rules = new ArrayList<V1beta1RuleWithOperationsBuilder>(); for (V1beta1RuleWithOperations item : rules){this.addToRules(item);}} else { this.rules = null;} return (A) this;
    }

    public A withRules(V1beta1RuleWithOperations... rules){
            if (this.rules != null) {this.rules.clear();}
            if (rules != null) {for (V1beta1RuleWithOperations item :rules){ this.addToRules(item);}} return (A) this;
    }

    public Boolean hasRules(){
            return rules != null && !rules.isEmpty();
    }

    public V1beta1WebhookFluent.RulesNested<A> addNewRule(){
            return new RulesNestedImpl();
    }

    public V1beta1WebhookFluent.RulesNested<A> addNewRuleLike(V1beta1RuleWithOperations item){
            return new RulesNestedImpl(-1, item);
    }

    public V1beta1WebhookFluent.RulesNested<A> setNewRuleLike(int index,V1beta1RuleWithOperations item){
            return new RulesNestedImpl(index, item);
    }

    public V1beta1WebhookFluent.RulesNested<A> editRule(int index){
            if (rules.size() <= index) throw new RuntimeException("Can't edit rules. Index exceeds size.");
            return setNewRuleLike(index, buildRule(index));
    }

    public V1beta1WebhookFluent.RulesNested<A> editFirstRule(){
            if (rules.size() == 0) throw new RuntimeException("Can't edit first rules. The list is empty.");
            return setNewRuleLike(0, buildRule(0));
    }

    public V1beta1WebhookFluent.RulesNested<A> editLastRule(){
            int index = rules.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last rules. The list is empty.");
            return setNewRuleLike(index, buildRule(index));
    }

    public V1beta1WebhookFluent.RulesNested<A> editMatchingRule(io.kubernetes.client.fluent.Predicate<V1beta1RuleWithOperationsBuilder> predicate){
            int index = -1;
            for (int i=0;i<rules.size();i++) { 
            if (predicate.apply(rules.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching rules. No match found.");
            return setNewRuleLike(index, buildRule(index));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta1WebhookFluentImpl that = (V1beta1WebhookFluentImpl) o;
            if (clientConfig != null ? !clientConfig.equals(that.clientConfig) :that.clientConfig != null) return false;
            if (failurePolicy != null ? !failurePolicy.equals(that.failurePolicy) :that.failurePolicy != null) return false;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            if (namespaceSelector != null ? !namespaceSelector.equals(that.namespaceSelector) :that.namespaceSelector != null) return false;
            if (rules != null ? !rules.equals(that.rules) :that.rules != null) return false;
            return true;
    }


    public class ClientConfigNestedImpl<N> extends V1beta1WebhookClientConfigFluentImpl<V1beta1WebhookFluent.ClientConfigNested<N>> implements V1beta1WebhookFluent.ClientConfigNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1beta1WebhookClientConfigBuilder builder;
    
            ClientConfigNestedImpl(V1beta1WebhookClientConfig item){
                    this.builder = new V1beta1WebhookClientConfigBuilder(this, item);
            }
            ClientConfigNestedImpl(){
                    this.builder = new V1beta1WebhookClientConfigBuilder(this);
            }
    
    public N and(){
            return (N) V1beta1WebhookFluentImpl.this.withClientConfig(builder.build());
    }
    public N endClientConfig(){
            return and();
    }

}
    public class NamespaceSelectorNestedImpl<N> extends V1LabelSelectorFluentImpl<V1beta1WebhookFluent.NamespaceSelectorNested<N>> implements V1beta1WebhookFluent.NamespaceSelectorNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1LabelSelectorBuilder builder;
    
            NamespaceSelectorNestedImpl(V1LabelSelector item){
                    this.builder = new V1LabelSelectorBuilder(this, item);
            }
            NamespaceSelectorNestedImpl(){
                    this.builder = new V1LabelSelectorBuilder(this);
            }
    
    public N and(){
            return (N) V1beta1WebhookFluentImpl.this.withNamespaceSelector(builder.build());
    }
    public N endNamespaceSelector(){
            return and();
    }

}
    public class RulesNestedImpl<N> extends V1beta1RuleWithOperationsFluentImpl<V1beta1WebhookFluent.RulesNested<N>> implements V1beta1WebhookFluent.RulesNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1beta1RuleWithOperationsBuilder builder;
        private final int index;
    
            RulesNestedImpl(int index,V1beta1RuleWithOperations item){
                    this.index = index;
                    this.builder = new V1beta1RuleWithOperationsBuilder(this, item);
            }
            RulesNestedImpl(){
                    this.index = -1;
                    this.builder = new V1beta1RuleWithOperationsBuilder(this);
            }
    
    public N and(){
            return (N) V1beta1WebhookFluentImpl.this.setToRules(index, builder.build());
    }
    public N endRule(){
            return and();
    }

}


}

==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1beta1WebhookFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.util.List;
import java.lang.Boolean;
import java.util.Collection;
import java.lang.Object;

public class V1beta1WebhookFluentImpl<A extends V1beta1WebhookFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta1WebhookFluent<A>{

    private V1beta1WebhookClientConfigBuilder clientConfig;
    private String failurePolicy;
    private String name;
    private V1LabelSelectorBuilder namespaceSelector;
    private List<V1beta1RuleWithOperationsBuilder> rules;
    private String sideEffects;

    public V1beta1WebhookFluentImpl(){
    }
    public V1beta1WebhookFluentImpl(V1beta1Webhook instance){
            this.withClientConfig(instance.getClientConfig());

            this.withFailurePolicy(instance.getFailurePolicy());

            this.withName(instance.getName());

            this.withNamespaceSelector(instance.getNamespaceSelector());

            this.withRules(instance.getRules());

            this.withSideEffects(instance.getSideEffects());

    }

    
/**
 * This method has been deprecated, please use method buildClientConfig instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1WebhookClientConfig getClientConfig(){
            return this.clientConfig!=null?this.clientConfig.build():null;
    }

    public V1beta1WebhookClientConfig buildClientConfig(){
            return this.clientConfig!=null?this.clientConfig.build():null;
    }

    public A withClientConfig(V1beta1WebhookClientConfig clientConfig){
            _visitables.remove(this.clientConfig);
            if (clientConfig!=null){ this.clientConfig= new V1beta1WebhookClientConfigBuilder(clientConfig); _visitables.add(this.clientConfig);} return (A) this;
    }

    public Boolean hasClientConfig(){
            return this.clientConfig != null;
    }

    public V1beta1WebhookFluent.ClientConfigNested<A> withNewClientConfig(){
            return new ClientConfigNestedImpl();
    }

    public V1beta1WebhookFluent.ClientConfigNested<A> withNewClientConfigLike(V1beta1WebhookClientConfig item){
            return new ClientConfigNestedImpl(item);
    }

    public V1beta1WebhookFluent.ClientConfigNested<A> editClientConfig(){
            return withNewClientConfigLike(getClientConfig());
    }

    public V1beta1WebhookFluent.ClientConfigNested<A> editOrNewClientConfig(){
            return withNewClientConfigLike(getClientConfig() != null ? getClientConfig(): new V1beta1WebhookClientConfigBuilder().build());
    }

    public V1beta1WebhookFluent.ClientConfigNested<A> editOrNewClientConfigLike(V1beta1WebhookClientConfig item){
            return withNewClientConfigLike(getClientConfig() != null ? getClientConfig(): item);
    }

    public String getFailurePolicy(){
            return this.failurePolicy;
    }

    public A withFailurePolicy(String failurePolicy){
            this.failurePolicy=failurePolicy; return (A) this;
    }

    public Boolean hasFailurePolicy(){
            return this.failurePolicy != null;
    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    
/**
 * This method has been deprecated, please use method buildNamespaceSelector instead.
 * @return The buildable object.
 */
@Deprecated public V1LabelSelector getNamespaceSelector(){
            return this.namespaceSelector!=null?this.namespaceSelector.build():null;
    }

    public V1LabelSelector buildNamespaceSelector(){
            return this.namespaceSelector!=null?this.namespaceSelector.build():null;
    }

    public A withNamespaceSelector(V1LabelSelector namespaceSelector){
            _visitables.remove(this.namespaceSelector);
            if (namespaceSelector!=null){ this.namespaceSelector= new V1LabelSelectorBuilder(namespaceSelector); _visitables.add(this.namespaceSelector);} return (A) this;
    }

    public Boolean hasNamespaceSelector(){
            return this.namespaceSelector != null;
    }

    public V1beta1WebhookFluent.NamespaceSelectorNested<A> withNewNamespaceSelector(){
            return new NamespaceSelectorNestedImpl();
    }

    public V1beta1WebhookFluent.NamespaceSelectorNested<A> withNewNamespaceSelectorLike(V1LabelSelector item){
            return new NamespaceSelectorNestedImpl(item);
    }

    public V1beta1WebhookFluent.NamespaceSelectorNested<A> editNamespaceSelector(){
            return withNewNamespaceSelectorLike(getNamespaceSelector());
    }

    public V1beta1WebhookFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelector(){
            return withNewNamespaceSelectorLike(getNamespaceSelector() != null ? getNamespaceSelector(): new V1LabelSelectorBuilder().build());
    }

    public V1beta1WebhookFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelectorLike(V1LabelSelector item){
            return withNewNamespaceSelectorLike(getNamespaceSelector() != null ? getNamespaceSelector(): item);
    }

    public A addToRules(int index,V1beta1RuleWithOperations item){
            if (this.rules == null) {this.rules = new ArrayList<V1beta1RuleWithOperationsBuilder>();}
            V1beta1RuleWithOperationsBuilder builder = new V1beta1RuleWithOperationsBuilder(item);_visitables.add(index >= 0 ? index : _visitables.size(), builder);this.rules.add(index >= 0 ? index : rules.size(), builder); return (A)this;
    }

    public A setToRules(int index,V1beta1RuleWithOperations item){
            if (this.rules == null) {this.rules = new ArrayList<V1beta1RuleWithOperationsBuilder>();}
            V1beta1RuleWithOperationsBuilder builder = new V1beta1RuleWithOperationsBuilder(item);
            if (index < 0 || index >= _visitables.size()) { _visitables.add(builder); } else { _visitables.set(index, builder);}
            if (index < 0 || index >= rules.size()) { rules.add(builder); } else { rules.set(index, builder);}
             return (A)this;
    }

    public A addToRules(V1beta1RuleWithOperations... items){
            if (this.rules == null) {this.rules = new ArrayList<V1beta1RuleWithOperationsBuilder>();}
            for (V1beta1RuleWithOperations item : items) {V1beta1RuleWithOperationsBuilder builder = new V1beta1RuleWithOperationsBuilder(item);_visitables.add(builder);this.rules.add(builder);} return (A)this;
    }

    public A addAllToRules(Collection<V1beta1RuleWithOperations> items){
            if (this.rules == null) {this.rules = new ArrayList<V1beta1RuleWithOperationsBuilder>();}
            for (V1beta1RuleWithOperations item : items) {V1beta1RuleWithOperationsBuilder builder = new V1beta1RuleWithOperationsBuilder(item);_visitables.add(builder);this.rules.add(builder);} return (A)this;
    }

    public A removeFromRules(V1beta1RuleWithOperations... items){
            for (V1beta1RuleWithOperations item : items) {V1beta1RuleWithOperationsBuilder builder = new V1beta1RuleWithOperationsBuilder(item);_visitables.remove(builder);if (this.rules != null) {this.rules.remove(builder);}} return (A)this;
    }

    public A removeAllFromRules(Collection<V1beta1RuleWithOperations> items){
            for (V1beta1RuleWithOperations item : items) {V1beta1RuleWithOperationsBuilder builder = new V1beta1RuleWithOperationsBuilder(item);_visitables.remove(builder);if (this.rules != null) {this.rules.remove(builder);}} return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildRules instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1RuleWithOperations> getRules(){
            return build(rules);
    }

    public List<V1beta1RuleWithOperations> buildRules(){
            return build(rules);
    }

    public V1beta1RuleWithOperations buildRule(int index){
            return this.rules.get(index).build();
    }

    public V1beta1RuleWithOperations buildFirstRule(){
            return this.rules.get(0).build();
    }

    public V1beta1RuleWithOperations buildLastRule(){
            return this.rules.get(rules.size() - 1).build();
    }

    public V1beta1RuleWithOperations buildMatchingRule(io.kubernetes.client.fluent.Predicate<V1beta1RuleWithOperationsBuilder> predicate){
            for (V1beta1RuleWithOperationsBuilder item: rules) { if(predicate.apply(item)){return item.build();} } return null;
    }

    public A withRules(List<V1beta1RuleWithOperations> rules){
            if (this.rules != null) { _visitables.removeAll(this.rules);}
            if (rules != null) {this.rules = new ArrayList<V1beta1RuleWithOperationsBuilder>(); for (V1beta1RuleWithOperations item : rules){this.addToRules(item);}} else { this.rules = null;} return (A) this;
    }

    public A withRules(V1beta1RuleWithOperations... rules){
            if (this.rules != null) {this.rules.clear();}
            if (rules != null) {for (V1beta1RuleWithOperations item :rules){ this.addToRules(item);}} return (A) this;
    }

    public Boolean hasRules(){
            return rules != null && !rules.isEmpty();
    }

    public V1beta1WebhookFluent.RulesNested<A> addNewRule(){
            return new RulesNestedImpl();
    }

    public V1beta1WebhookFluent.RulesNested<A> addNewRuleLike(V1beta1RuleWithOperations item){
            return new RulesNestedImpl(-1, item);
    }

    public V1beta1WebhookFluent.RulesNested<A> setNewRuleLike(int index,V1beta1RuleWithOperations item){
            return new RulesNestedImpl(index, item);
    }

    public V1beta1WebhookFluent.RulesNested<A> editRule(int index){
            if (rules.size() <= index) throw new RuntimeException("Can't edit rules. Index exceeds size.");
            return setNewRuleLike(index, buildRule(index));
    }

    public V1beta1WebhookFluent.RulesNested<A> editFirstRule(){
            if (rules.size() == 0) throw new RuntimeException("Can't edit first rules. The list is empty.");
            return setNewRuleLike(0, buildRule(0));
    }

    public V1beta1WebhookFluent.RulesNested<A> editLastRule(){
            int index = rules.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last rules. The list is empty.");
            return setNewRuleLike(index, buildRule(index));
    }

    public V1beta1WebhookFluent.RulesNested<A> editMatchingRule(io.kubernetes.client.fluent.Predicate<V1beta1RuleWithOperationsBuilder> predicate){
            int index = -1;
            for (int i=0;i<rules.size();i++) { 
            if (predicate.apply(rules.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching rules. No match found.");
            return setNewRuleLike(index, buildRule(index));
    }

    public String getSideEffects(){
            return this.sideEffects;
    }

    public A withSideEffects(String sideEffects){
            this.sideEffects=sideEffects; return (A) this;
    }

    public Boolean hasSideEffects(){
            return this.sideEffects != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta1WebhookFluentImpl that = (V1beta1WebhookFluentImpl) o;
            if (clientConfig != null ? !clientConfig.equals(that.clientConfig) :that.clientConfig != null) return false;
            if (failurePolicy != null ? !failurePolicy.equals(that.failurePolicy) :that.failurePolicy != null) return false;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            if (namespaceSelector != null ? !namespaceSelector.equals(that.namespaceSelector) :that.namespaceSelector != null) return false;
            if (rules != null ? !rules.equals(that.rules) :that.rules != null) return false;
            if (sideEffects != null ? !sideEffects.equals(that.sideEffects) :that.sideEffects != null) return false;
            return true;
    }


    public class ClientConfigNestedImpl<N> extends V1beta1WebhookClientConfigFluentImpl<V1beta1WebhookFluent.ClientConfigNested<N>> implements V1beta1WebhookFluent.ClientConfigNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1beta1WebhookClientConfigBuilder builder;
    
            ClientConfigNestedImpl(V1beta1WebhookClientConfig item){
                    this.builder = new V1beta1WebhookClientConfigBuilder(this, item);
            }
            ClientConfigNestedImpl(){
                    this.builder = new V1beta1WebhookClientConfigBuilder(this);
            }
    
    public N and(){
            return (N) V1beta1WebhookFluentImpl.this.withClientConfig(builder.build());
    }
    public N endClientConfig(){
            return and();
    }

}
    public class NamespaceSelectorNestedImpl<N> extends V1LabelSelectorFluentImpl<V1beta1WebhookFluent.NamespaceSelectorNested<N>> implements V1beta1WebhookFluent.NamespaceSelectorNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1LabelSelectorBuilder builder;
    
            NamespaceSelectorNestedImpl(V1LabelSelector item){
                    this.builder = new V1LabelSelectorBuilder(this, item);
            }
            NamespaceSelectorNestedImpl(){
                    this.builder = new V1LabelSelectorBuilder(this);
            }
    
    public N and(){
            return (N) V1beta1WebhookFluentImpl.this.withNamespaceSelector(builder.build());
    }
    public N endNamespaceSelector(){
            return and();
    }

}
    public class RulesNestedImpl<N> extends V1beta1RuleWithOperationsFluentImpl<V1beta1WebhookFluent.RulesNested<N>> implements V1beta1WebhookFluent.RulesNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1beta1RuleWithOperationsBuilder builder;
        private final int index;
    
            RulesNestedImpl(int index,V1beta1RuleWithOperations item){
                    this.index = index;
                    this.builder = new V1beta1RuleWithOperationsBuilder(this, item);
            }
            RulesNestedImpl(){
                    this.index = -1;
                    this.builder = new V1beta1RuleWithOperationsBuilder(this);
            }
    
    public N and(){
            return (N) V1beta1WebhookFluentImpl.this.setToRules(index, builder.build());
    }
    public N endRule(){
            return and();
    }

}


}
